void processFrontConnected(Task *task);

void processFrontDisconnected(Task *task);

void processRspError(Task *task);

void processRtnOrder(Task *task);

void processRtnTrade(Task *task);

void processErrRtnOrderAction(Task *task);

void processRspOrderInsert(Task *task);

void processRspOrderAction(Task *task);

void processRspLogin(Task *task);

void processRspUserPasswordUpdate(Task *task);

void processRspTransferInsert(Task *task);

void processRtnTransfer(Task *task);

void processRspFundPaybackInsert(Task *task);

void processRtnFundPayback(Task *task);

void processRspStockPaybackInsert(Task *task);

void processRtnStockPayback(Task *task);

void processRtnPrivateCreditStock(Task *task);

void processRtnLock(Task *task);

void processRspLockInsert(Task *task);

void processRtnExecOrder(Task *task);

void processRspExecOrderInsert(Task *task);

void processRspExecOrderAction(Task *task);

void processErrRtnExecOrderAction(Task *task);

void processRspQryInstrument(Task *task);

void processRspQryDepthMarketData(Task *task);

void processRspQryInvestorPosition(Task *task);

void processRspQryTradingAccount(Task *task);

void processRspQryOptionInstrMarginByVolume(Task *task);

void processRspQryOptionInstrCommRate(Task *task);

void processRspQryOrder(Task *task);

void processRspQryTrade(Task *task);

void processRspQryInstrumentCommissionRate(Task *task);

void processRspQryInvestor(Task *task);

void processRspQryTransfer(Task *task);

void processRspQryTradingCode(Task *task);

void processRspQryMaxOrderVolume(Task *task);

void processRspQryCreditInstrument(Task *task);

void processRspQryCreditInvestor(Task *task);

void processRspQryPrivateCreditStock(Task *task);

void processRspQryCreditConcentration(Task *task);

void processRspQryCreditFundDetail(Task *task);

void processRspQryCreditStockDetail(Task *task);

void processRspQryFundPayback(Task *task);

void processRspQryStockPayback(Task *task);

void processRspQryPublicCreditFund(Task *task);

void processRspQryETFInfo(Task *task);

void processRspQryETFComponent(Task *task);

void processRspQryCreditAvailableDetail(Task *task);

void processRspQryLock(Task *task);

void processRspQryExecOrder(Task *task);

void processRspQryLockPosition(Task *task);

void processRspQryOptPosiLimit(Task *task);

void processRspQryOptAmountLimit(Task *task);

